@@ -1,32 +1,28 @@
-/**************************************************************************
- *  Kchmviewer - a portable CHM file viewer with the best support for     *
- *  the international languages                                           *
- *                                                                        *
- *  Copyright (C) 2004-2012 George Yunaev, kchmviewer@ulduzsoft.com       *
- *                                                                        *
- *  Please read http://www.kchmviewer.net/reportbugs.html if you want     *
- *  to report a bug. It lists things I need to fix it!                    *
- *                                                                        *
- *  This program is free software: you can redistribute it and/or modify  *
- *  it under the terms of the GNU General Public License as published by  *
- *  the Free Software Foundation, either version 3 of the License, or     *
- *  (at your option) any later version.                                   *
- *																	      *
- *  This program is distributed in the hope that it will be useful,       *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *  GNU General Public License for more details.                          *
- *                                                                        *
- *  You should have received a copy of the GNU General Public License     *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- **************************************************************************/
+/*
+ *  Kchmviewer - a CHM and EPUB file viewer with broad language support
+ *  Copyright (C) 2004-2014 George Yunaev, gyunaev@ulduzsoft.com
+ *
+ *  This program is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
-#include "libchmfile.h"
-
+#include <QSharedMemory>
 #include "kde-qt.h"
+#include "ebook.h"
 #include "viewwindow.h"
 #include "checknewversion.h"
 
@@ -60,20 +56,19 @@ class MainWindow : public QMainWindow, public Ui::MainWindow
 		enum
 		{
 			OPF_CONTENT_TREE = 1 << 0,	//! Locate this page in the content tree
-			OPF_ADD2HISTORY	= 1 << 1,	//! Add the previous page into the history
 			OPF_NEW_TAB = 1 << 2,		//! Open the page in a new tab
 			OPF_BACKGROUND 	= 1 << 3	//! Open the page in a new tab in background
 		};
 		
 	public:
-		MainWindow();
+        MainWindow( const QStringList& arguments );
 		~MainWindow();
 	
-		bool		openPage ( const QString &url, unsigned int flags = OPF_CONTENT_TREE );
+		bool		openPage (const QUrl &url, unsigned int flags = OPF_CONTENT_TREE );
 		
-		LCHMFile *	chmFile() const	{ return m_chmFile; }
-		const QString&	getOpenedFileName () { return m_chmFilename; }
-		const QString&	getOpenedFileBaseName () { return m_chmFileBasename; }
+		EBook	*	chmFile() const	{ return m_ebookFile; }
+		const QString&	getOpenedFileName () { return m_ebookFilename; }
+		const QString&	getOpenedFileBaseName () { return m_ebookFileBasename; }
 		
 		ViewWindow * currentBrowser() const;
 		Settings   * currentSettings() const { return m_currentSettings; }
@@ -81,9 +76,14 @@ class MainWindow : public QMainWindow, public Ui::MainWindow
 		NavigationPanel * navigator() const { return m_navPanel; }
 
 		void		showInStatusBar (const QString& text);
-		void		setTextEncoding (const LCHMTextEncoding * enc);
+		void		setTextEncoding (const QString &enc);
 		QMenu * 	tabItemsContextMenu();
-	
+        void        launch();
+
+        // Returns true if there's another instance running with the same token (assuming there's token);
+        // also sends the command-line data there so it runs properly.
+        bool        hasSameTokenInstance();
+
 		// Called from WindowMgr when another browser tab is activated
 		void		browserChanged( ViewWindow * newbrowser );
 	
@@ -94,6 +94,9 @@ class MainWindow : public QMainWindow, public Ui::MainWindow
 		bool		hasTableOfContents() const;
 		bool		hasIndex() const;
 
+		// Gets the appropriate CHM pixmap icon (there are no icons in EPUB).
+		const QPixmap * getEBookIconPixmap( EBookTocEntry::Icon imagenum );
+
 	public slots:
 		// Navigation toolbar icons
 		void		navSetBackEnabled( bool enabled );
@@ -135,7 +138,6 @@ class MainWindow : public QMainWindow, public Ui::MainWindow
 		void		actionEncodingChanged( QAction * action );
 	
 		// Link activation
-		void 		activateLink( const QString & link );
 		void 		activateUrl( const QUrl & link );
 
 		void		updateToolbars();
@@ -151,13 +153,16 @@ class MainWindow : public QMainWindow, public Ui::MainWindow
 		void		newVerAvailError( int  );
 		void		newVerAvailable( NewVersionMetaMap metadata );
 		
+        // single app mode
+        void        checkForSharedMemoryMessage();
+
 	protected:
 		// Reimplemented functions
 		void		closeEvent ( QCloseEvent * e );
 		bool		event ( QEvent * e );
 		
 	private:
-		bool		parseCmdLineArgs();
+        bool		parseCmdLineArgs(const QStringList &args, bool from_another_app = false );
 		void 		setupActions();
 		void		setupLangEncodingMenu();
 		
@@ -166,13 +171,14 @@ class MainWindow : public QMainWindow, public Ui::MainWindow
 		void		refreshCurrentBrowser();
 		
 		bool		handleUserEvent( const UserEvent * event );
-		
+        void        printHelpAndExit();
+
 	private:		
-		QString 				m_chmFilename;
-		QString 				m_chmFileBasename;
+		QString 				m_ebookFilename;
+		QString 				m_ebookFileBasename;
 		
 		Settings			*	m_currentSettings;
-		LCHMFile			*	m_chmFile;
+		EBook				*	m_ebookFile;
 		
 		QList<QTemporaryFile*>	m_tempFileKeeper;
 
@@ -185,6 +191,16 @@ class MainWindow : public QMainWindow, public Ui::MainWindow
 		NavigationPanel		*	m_navPanel;
 		ToolbarManager		*	m_toolbarMgr;
 
+        // For a single instance mode
+        QSharedMemory       *   m_sharedMemory;
+
+		// Storage for built-in icons
+		QPixmap				 	m_builtinIcons[ EBookTocEntry::MAX_BUILTIN_ICONS ];
+
+        // Storage for command-line arguments due to KDE really insisting to use its own way
+        // for command-line parsing.
+        QStringList             m_arguments;
+
 	private:
 		// This is used for application automatic testing
 		enum	auto_test_state_t
@@ -196,8 +212,8 @@ class MainWindow : public QMainWindow, public Ui::MainWindow
 		};
 		
 		auto_test_state_t			m_autoteststate;
-	
-	private slots:
+
+private slots:
 		void	runAutoTest();
 		
 };
